@@ -568,7 +568,7 @@ lookup_cd (SjMetadata *metadata)
           int matched, year=1, month=1, day=1;
           matched = sscanf(data, "%u-%u-%u", &year, &month, &day);
           if (matched >= 1) {
-            album->release_date = g_date_new_dmy (day, month, year);
+            album->release_date = g_date_new_dmy ((day == 0) ? 1 : day, (month == 0) ? 1 : month, year);
           }
         }
         mb_Select(priv->mb, MBS_Back);
